@@ -11,7 +11,7 @@ import (
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/archives"
-	"gitlab.com/gitlab-org/gitlab-runner/helpers/url"
+	url_helpers "gitlab.com/gitlab-org/gitlab-runner/helpers/url"
 	"gitlab.com/gitlab-org/gitlab-runner/log"
 )
 
@@ -47,7 +47,7 @@ func (c *CacheArchiverCommand) upload() error {
 		return err
 	}
 
-	req, err := http.NewRequest("PUT", c.URL, file)
+	req, err := http.NewRequest(http.MethodPut, c.URL, file)
 	if err != nil {
 		return retryableErr{err: err}
 	}
