@@ -7,7 +7,6 @@ import (
 	"fmt"
 	"io"
 	"os"
-	"path"
 	"path/filepath"
 	"regexp"
 	"sort"
@@ -16,12 +15,12 @@ import (
 	"sync"
 	"time"
 
+	"github.com/bmatcuk/doublestar"
 	"github.com/docker/docker/api/types"
 	"github.com/docker/docker/api/types/container"
 	"github.com/docker/docker/api/types/network"
 	"github.com/docker/docker/pkg/stdcopy"
 	"github.com/kardianos/osext"
-	"github.com/mattn/go-zglob"
 	"github.com/sirupsen/logrus"
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
@@ -29,11 +28,12 @@ import (
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/networks"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes"
 	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes/parser"
+	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/volumes/permission"
+	"gitlab.com/gitlab-org/gitlab-runner/executors/docker/internal/wait"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/helperimage"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/container/services"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/docker"
-	"gitlab.com/gitlab-org/gitlab-runner/helpers/featureflags"
 )
 
 const (
@@ -62,9 +62,10 @@ var errNetworksManagerUndefined = errors.New("networksManager is undefined")
 
 type executor struct {
 	executors.AbstractExecutor
-	client       docker.Client
-	volumeParser parser.Parser
-	info         types.Info
+	client                    docker.Client
+	volumeParser              parser.Parser
+	newVolumePermissionSetter func() (permission.Setter, error)
+	info                      types.Info
 
 	temporary []string // IDs of containers that should be removed
 
@@ -148,7 +149,6 @@ func (e *executor) getHomeDirAuthConfiguration(indexName string) (string, *types
 		return "", nil
 	}
 	return sourceFile, docker.ResolveDockerAuthConfig(indexName, authConfigs)
-
 }
 
 type authConfigResolver func(indexName string) (string, *types.AuthConfig)
@@ -427,10 +427,7 @@ func (e *executor) wasImageUsed(imageName, imageID string) bool {
 	e.usedImagesLock.RLock()
 	defer e.usedImagesLock.RUnlock()
 
-	if e.usedImages[imageName] == imageID {
-		return true
-	}
-	return false
+	return e.usedImages[imageName] == imageID
 }
 
 func (e *executor) markImageAsUsed(imageName, imageID string) {
@@ -534,7 +531,7 @@ func (e *executor) getProjectUniqRandomizedName() string {
 }
 
 func (e *executor) getServicesDefinitions() (common.Services, error) {
-	internalServiceImages := []string{}
+	var internalServiceImages []string
 	serviceDefinitions := common.Services{}
 
 	for _, service := range e.Config.Docker.Services {
@@ -690,18 +687,6 @@ func (e *executor) createServices() (err error) {
 	return
 }
 
-func (e *executor) getValidContainers(containers []string) []string {
-	var newContainers []string
-
-	for _, container := range containers {
-		if _, err := e.client.ContainerInspect(e.Context, container); err == nil {
-			newContainers = append(newContainers, container)
-		}
-	}
-
-	return newContainers
-}
-
 func (e *executor) createContainer(containerType string, imageDefinition common.Image, cmd []string, allowedInternalImages []string) (*types.ContainerJSON, error) {
 	if e.volumesManager == nil {
 		return nil, errVolumesManagerUndefined
@@ -770,7 +755,7 @@ func (e *executor) createContainer(containerType string, imageDefinition common.
 		OomScoreAdj:   e.Config.Docker.OomScoreAdjust,
 		ShmSize:       e.Config.Docker.ShmSize,
 		VolumeDriver:  e.Config.Docker.VolumeDriver,
-		VolumesFrom:   append(e.Config.Docker.VolumesFrom),
+		VolumesFrom:   e.Config.Docker.VolumesFrom,
 		LogConfig: container.LogConfig{
 			Type: "json-file",
 		},
@@ -824,43 +809,9 @@ func (e *executor) killContainer(id string, waitCh chan error) (err error) {
 func (e *executor) waitForContainer(ctx context.Context, id string) error {
 	e.Debugln("Waiting for container", id, "...")
 
-	retries := 0
+	waiter := wait.NewDockerWaiter(e.client)
 
-	// Use active wait
-	for ctx.Err() == nil {
-		container, err := e.client.ContainerInspect(ctx, id)
-		if err != nil {
-			if docker.IsErrNotFound(err) {
-				return err
-			}
-
-			if retries > 3 {
-				return err
-			}
-
-			retries++
-			time.Sleep(time.Second)
-			continue
-		}
-
-		// Reset retry timer
-		retries = 0
-
-		if container.State.Running {
-			time.Sleep(time.Second)
-			continue
-		}
-
-		if container.State.ExitCode != 0 {
-			return &common.BuildError{
-				Inner: fmt.Errorf("exit code %d", container.State.ExitCode),
-			}
-		}
-
-		return nil
-	}
-
-	return ctx.Err()
+	return waiter.Wait(ctx, id)
 }
 
 func (e *executor) watchContainer(ctx context.Context, id string, input io.Reader) (err error) {
@@ -966,12 +917,11 @@ func (e *executor) disconnectNetwork(ctx context.Context, id string) {
 			}
 		}
 	}
-	return
 }
 
 func (e *executor) verifyAllowedImage(image, optionName string, allowedImages []string, internalImages []string) error {
 	for _, allowedImage := range allowedImages {
-		ok, _ := zglob.Match(allowedImage, image)
+		ok, _ := doublestar.Match(allowedImage, image)
 		if ok {
 			return nil
 		}
@@ -1084,19 +1034,6 @@ func (e *executor) createDependencies() error {
 		e.createServices,
 	}
 
-	if e.Build.IsFeatureFlagOn(featureflags.UseLegacyVolumesMountingOrder) {
-		// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/4180
-		createDependenciesStrategy = []func() error{
-			e.createNetworksManager,
-			e.createBuildNetwork,
-			e.bindDevices,
-			e.createVolumesManager,
-			e.createBuildVolume,
-			e.createServices,
-			e.createVolumes,
-		}
-	}
-
 	for _, setup := range createDependenciesStrategy {
 		err := setup()
 		if err != nil {
@@ -1143,14 +1080,6 @@ func (e *executor) createBuildVolume() error {
 
 	jobsDir := e.Build.RootDir
 
-	// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/4180
-	if e.Build.IsFeatureFlagOn(featureflags.UseLegacyBuildsDirForDocker) {
-		// Cache Git sources:
-		// take path of the projects directory,
-		// because we use `rm -rf` which could remove the mounted volume
-		jobsDir = path.Dir(e.Build.FullProjectDir())
-	}
-
 	var err error
 
 	if e.Build.GetGitStrategy() == common.GitFetch {
