@@ -45,12 +45,12 @@ func TestMain(m *testing.M) {
 
 // ImagePullOptions contains the RegistryAuth which is inferred from the docker
 // configuration for the user, so just mock it out here.
-func buildImagePullOptions(e executor, configName string) mock.AnythingOfTypeArgument {
+func buildImagePullOptions(e *executor, configName string) mock.AnythingOfTypeArgument {
 	return mock.AnythingOfType("ImagePullOptions")
 }
 
 func TestParseDeviceStringOne(t *testing.T) {
-	e := executor{}
+	e := new(executor)
 
 	device, err := e.parseDeviceString("/dev/kvm")
 
@@ -61,7 +61,7 @@ func TestParseDeviceStringOne(t *testing.T) {
 }
 
 func TestParseDeviceStringTwo(t *testing.T) {
-	e := executor{}
+	e := new(executor)
 
 	device, err := e.parseDeviceString("/dev/kvm:/devices/kvm")
 
@@ -72,7 +72,7 @@ func TestParseDeviceStringTwo(t *testing.T) {
 }
 
 func TestParseDeviceStringThree(t *testing.T) {
-	e := executor{}
+	e := new(executor)
 
 	device, err := e.parseDeviceString("/dev/kvm:/devices/kvm:r")
 
@@ -83,7 +83,7 @@ func TestParseDeviceStringThree(t *testing.T) {
 }
 
 func TestParseDeviceStringFour(t *testing.T) {
-	e := executor{}
+	e := new(executor)
 
 	_, err := e.parseDeviceString("/dev/kvm:/devices/kvm:r:oops")
 
@@ -132,7 +132,7 @@ var testAllowedImages = []testAllowedImageDescription{
 }
 
 func TestVerifyAllowedImage(t *testing.T) {
-	e := executor{}
+	e := new(executor)
 
 	for _, test := range testAllowedImages {
 		err := e.verifyAllowedImage(test.image, "", test.allowedImages, []string{})
@@ -158,7 +158,7 @@ func testServiceFromNamedImage(t *testing.T, description, imageName, serviceName
 	})
 	networkID := "network-id"
 
-	e := executor{
+	e := &executor{
 		client: c,
 		info: types.Info{
 			OSType:       helperimage.OSTypeLinux,
@@ -244,7 +244,7 @@ func TestDockerForNamedImage(t *testing.T) {
 	defer c.AssertExpectations(t)
 	validSHA := "real@sha256:b5bb9d8014a0f9b1d61e21e796d78dccdf1352f23cd32812f4850b878ae4944c"
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	options := buildImagePullOptions(e, "test")
 
@@ -277,7 +277,7 @@ func TestDockerForExistingImage(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	options := buildImagePullOptions(e, "existing")
 
@@ -308,7 +308,7 @@ func TestHelperImageWithVariable(t *testing.T) {
 		Return(types.ImageInspect{ID: "helper-image"}, nil, nil).
 		Once()
 
-	e := executor{
+	e := &executor{
 		AbstractExecutor: executors.AbstractExecutor{
 			Build: &common.Build{
 				JobResponse: common.JobResponse{},
@@ -343,7 +343,7 @@ func TestDockerGetImageById(t *testing.T) {
 	defer c.AssertExpectations(t)
 
 	// Use default policy
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode("")
 
@@ -361,7 +361,7 @@ func TestDockerUnknownPolicyMode(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode("unknown")
 
@@ -373,7 +373,7 @@ func TestDockerPolicyModeNever(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyNever)
 
@@ -397,7 +397,7 @@ func TestDockerPolicyModeIfNotPresentForExistingImage(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyIfNotPresent)
 
@@ -414,7 +414,7 @@ func TestDockerPolicyModeIfNotPresentForNotExistingImage(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyIfNotPresent)
 
@@ -449,7 +449,7 @@ func TestDockerPolicyModeAlwaysForExistingImage(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyAlways)
 
@@ -475,7 +475,7 @@ func TestDockerPolicyModeAlwaysForLocalOnlyImage(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyAlways)
 
@@ -497,7 +497,7 @@ func TestDockerGetExistingDockerImageIfPullFails(t *testing.T) {
 	c := new(docker.MockClient)
 	defer c.AssertExpectations(t)
 
-	e := executor{client: c}
+	e := &executor{client: c}
 	e.Context = context.Background()
 	e.setPolicyMode(common.PullPolicyAlways)
 
@@ -981,40 +981,6 @@ func TestCreateBuildVolume(t *testing.T) {
 			},
 			createVolumeManager: true,
 		},
-		"git strategy fetch, non-empty buildsDir, no error, legacy builds dir": {
-			// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/4180
-			gitStrategy: "fetch",
-			buildsDir:   "/builds",
-			adjustConfiguration: func(e *executor) {
-				e.Build.Variables = append(e.Build.Variables, common.JobVariable{
-					Key:   featureflags.UseLegacyBuildsDirForDocker,
-					Value: "true",
-				})
-			},
-			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("Create", mock.Anything, "/builds/group").
-					Return(nil).
-					Once()
-			},
-			createVolumeManager: true,
-		},
-		"git strategy clone, non-empty buildsDir, no error, legacy builds dir": {
-			// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/4180
-			gitStrategy: "clone",
-			buildsDir:   "/builds",
-			adjustConfiguration: func(e *executor) {
-				e.Build.Variables = append(e.Build.Variables, common.JobVariable{
-					Key:   featureflags.UseLegacyBuildsDirForDocker,
-					Value: "true",
-				})
-			},
-			volumesManagerAssertions: func(vm *volumes.MockManager) {
-				vm.On("CreateTemporary", mock.Anything, "/builds/group").
-					Return(nil).
-					Once()
-			},
-			createVolumeManager: true,
-		},
 	}
 
 	for testName, test := range tests {
@@ -1038,100 +1004,76 @@ func TestCreateDependencies(t *testing.T) {
 	})
 	testError := errors.New("test-error")
 
-	tests := map[string]struct {
-		legacyVolumesMountingOrder string
-		expectedServiceVolumes     []string
-	}{
-		"UseLegacyVolumesMountingOrder is false": {
-			legacyVolumesMountingOrder: "false",
-			expectedServiceVolumes:     []string{"/volume", "/builds"},
-		},
-		// TODO: Remove in 13.0 https://gitlab.com/gitlab-org/gitlab-runner/issues/6581
-		"UseLegacyVolumesMountingOrder is true": {
-			legacyVolumesMountingOrder: "true",
-			expectedServiceVolumes:     []string{"/builds"},
-		},
-	}
+	testCase := volumesTestCase{
+		buildsDir: "/builds",
+		volumes:   []string{"/volume"},
+		adjustConfiguration: func(e *executor) {
+			e.Build.Services = append(e.Build.Services, common.Image{
+				Name: "alpine:latest",
+			})
 
-	for testName, test := range tests {
-		t.Run(testName, func(t *testing.T) {
-			testCase := volumesTestCase{
-				buildsDir: "/builds",
-				volumes:   []string{"/volume"},
-				adjustConfiguration: func(e *executor) {
-					e.Build.Services = append(e.Build.Services, common.Image{
-						Name: "alpine:latest",
-					})
-
-					e.Build.Variables = append(e.Build.Variables, common.JobVariable{
-						Key:   featureflags.UseLegacyVolumesMountingOrder,
-						Value: test.legacyVolumesMountingOrder,
-					})
-
-					e.BuildShell = &common.ShellConfiguration{
-						Environment: []string{},
-					}
-				},
-				volumesManagerAssertions: func(vm *volumes.MockManager) {
-					binds := make([]string, 0)
-
-					vm.On("CreateTemporary", mock.Anything, "/builds").
-						Return(nil).
-						Run(func(args mock.Arguments) {
-							binds = append(binds, args.Get(1).(string))
-						}).
-						Once()
-					vm.On("Create", mock.Anything, "/volume").
-						Return(nil).
-						Run(func(args mock.Arguments) {
-							binds = append(binds, args.Get(1).(string))
-						}).
-						Maybe() // In the FF enabled case this assertion will be not met because of error during service starts
-					vm.On("Binds").
-						Return(func() []string {
-							return binds
-						}).
-						Once()
-				},
-				clientAssertions: func(c *docker.MockClient) {
-					hostConfigMatcher := mock.MatchedBy(func(conf *container.HostConfig) bool {
-						return assert.Equal(t, test.expectedServiceVolumes, conf.Binds)
-					})
-
-					c.On("ImageInspectWithRaw", mock.Anything, "alpine:latest").
-						Return(types.ImageInspect{}, nil, nil).
-						Once()
-					c.On("NetworkList", mock.Anything, mock.Anything).
-						Return(nil, nil).
-						Times(2)
-					c.On("ContainerRemove", mock.Anything, containerNameMatcher, mock.Anything).
-						Return(nil).
-						Once()
-					c.On("ContainerRemove", mock.Anything, containerID, mock.Anything).
-						Return(nil).
-						Once()
-					c.On("ContainerCreate", mock.Anything, mock.Anything, hostConfigMatcher, mock.Anything, containerNameMatcher).
-						Return(container.ContainerCreateCreatedBody{ID: containerID}, nil).
-						Once()
-					c.On("ContainerStart", mock.Anything, containerID, mock.Anything).
-						Return(testError).
-						Once()
-				},
+			e.BuildShell = &common.ShellConfiguration{
+				Environment: []string{},
 			}
+		},
+		volumesManagerAssertions: func(vm *volumes.MockManager) {
+			binds := make([]string, 0)
 
-			e, closureFn := getExecutorForVolumesTests(t, testCase)
-			defer closureFn()
+			vm.On("CreateTemporary", mock.Anything, "/builds").
+				Return(nil).
+				Run(func(args mock.Arguments) {
+					binds = append(binds, args.Get(1).(string))
+				}).
+				Once()
+			vm.On("Create", mock.Anything, "/volume").
+				Return(nil).
+				Run(func(args mock.Arguments) {
+					binds = append(binds, args.Get(1).(string))
+				}).
+				Once()
+			vm.On("Binds").
+				Return(func() []string {
+					return binds
+				}).
+				Once()
+		},
+		clientAssertions: func(c *docker.MockClient) {
+			hostConfigMatcher := mock.MatchedBy(func(conf *container.HostConfig) bool {
+				return assert.Equal(t, []string{"/volume", "/builds"}, conf.Binds)
+			})
 
-			err := e.createDependencies()
-			assert.Equal(t, testError, err)
-		})
+			c.On("ImageInspectWithRaw", mock.Anything, "alpine:latest").
+				Return(types.ImageInspect{}, nil, nil).
+				Once()
+			c.On("NetworkList", mock.Anything, mock.Anything).
+				Return(nil, nil).
+				Times(2)
+			c.On("ContainerRemove", mock.Anything, containerNameMatcher, mock.Anything).
+				Return(nil).
+				Once()
+			c.On("ContainerRemove", mock.Anything, containerID, mock.Anything).
+				Return(nil).
+				Once()
+			c.On("ContainerCreate", mock.Anything, mock.Anything, hostConfigMatcher, mock.Anything, containerNameMatcher).
+				Return(container.ContainerCreateCreatedBody{ID: containerID}, nil).
+				Once()
+			c.On("ContainerStart", mock.Anything, containerID, mock.Anything).
+				Return(testError).
+				Once()
+		},
 	}
+
+	e, closureFn := getExecutorForVolumesTests(t, testCase)
+	defer closureFn()
+
+	err = e.createDependencies()
+	assert.Equal(t, testError, err)
 }
 
 var testFileAuthConfigs = `{"auths":{"https://registry.domain.tld:5005/v1/":{"auth":"aW52YWxpZF91c2VyOmludmFsaWRfcGFzc3dvcmQ="},"registry2.domain.tld:5005":{"auth":"dGVzdF91c2VyOnRlc3RfcGFzc3dvcmQ="}}}`
 var testVariableAuthConfigs = `{"auths":{"https://registry.domain.tld:5005/v1/":{"auth":"dGVzdF91c2VyOnRlc3RfcGFzc3dvcmQ="}}}`
 
-func getAuthConfigTestExecutor(t *testing.T, precreateConfigFile bool) executor {
+func getAuthConfigTestExecutor(t *testing.T, precreateConfigFile bool) *executor {
 	tempHomeDir, err := ioutil.TempDir("", "docker-auth-configs-test")
 	require.NoError(t, err)
 
@@ -1144,7 +1086,7 @@ func getAuthConfigTestExecutor(t *testing.T, precreateConfigFile bool) executor
 		docker.HomeDirectory = ""
 	}
 
-	e := executor{}
+	e := new(executor)
 	e.Build = &common.Build{
 		Runner: &common.RunnerConfig{},
 	}
@@ -1199,13 +1141,13 @@ func assertCredentials(t *testing.T, serverAddress, username, password string, a
 	assert.Equal(t, password, ac.Password, "Password for %v", messageElements)
 }
 
-func getTestAuthConfig(t *testing.T, e executor, imageName string) *types.AuthConfig {
+func getTestAuthConfig(t *testing.T, e *executor, imageName string) *types.AuthConfig {
 	ac := e.getAuthConfig(imageName)
 
 	return ac
 }
 
-func testVariableAuthConfig(t *testing.T, e executor) {
+func testVariableAuthConfig(t *testing.T, e *executor) {
 	t.Run("withoutGitLabRegistry", func(t *testing.T) {
 		ac := getTestAuthConfig(t, e, "registry.domain.tld:5005/image/name:version")
 		assertCredentials(t, "https://registry.domain.tld:5005/v1/", "test_user", "test_password", ac, "registry.domain.tld:5005/image/name:version")
@@ -1218,7 +1160,7 @@ func testVariableAuthConfig(t *testing.T, e executor) {
 	})
 
 	t.Run("withGitLabRegistry", func(t *testing.T) {
-		addGitLabRegistryCredentials(&e)
+		addGitLabRegistryCredentials(e)
 
 		ac := getTestAuthConfig(t, e, "registry.domain.tld:5005/image/name:version")
 		assertCredentials(t, "https://registry.domain.tld:5005/v1/", "test_user", "test_password", ac, "registry.domain.tld:5005/image/name:version")
@@ -1233,14 +1175,14 @@ func testVariableAuthConfig(t *testing.T, e executor) {
 
 func TestGetRemoteVariableAuthConfig(t *testing.T) {
 	e := getAuthConfigTestExecutor(t, true)
-	addRemoteVariableCredentials(&e)
+	addRemoteVariableCredentials(e)
 
 	testVariableAuthConfig(t, e)
 }
 
 func TestGetLocalVariableAuthConfig(t *testing.T) {
 	e := getAuthConfigTestExecutor(t, true)
-	addLocalVariableCredentials(&e)
+	addLocalVariableCredentials(e)
 
 	testVariableAuthConfig(t, e)
 }
@@ -1261,7 +1203,7 @@ func TestGetDefaultAuthConfig(t *testing.T) {
 
 	t.Run("withGitLabRegistry", func(t *testing.T) {
 		e := getAuthConfigTestExecutor(t, false)
-		addGitLabRegistryCredentials(&e)
+		addGitLabRegistryCredentials(e)
 
 		ac := getTestAuthConfig(t, e, "docker:dind")
 		assertEmptyCredentials(t, ac, "docker:dind")
@@ -1282,7 +1224,7 @@ func TestAuthConfigOverwritingOrder(t *testing.T) {
 
 	t.Run("gitlabRegistryOnly", func(t *testing.T) {
 		e := getAuthConfigTestExecutor(t, false)
-		addGitLabRegistryCredentials(&e)
+		addGitLabRegistryCredentials(e)
 
 		ac := getTestAuthConfig(t, e, imageName)
 		assertCredentials(t, "registry.gitlab.tld:1234", "gitlab-ci-token", e.Build.Token, ac, imageName)
@@ -1290,8 +1232,8 @@ func TestAuthConfigOverwritingOrder(t *testing.T) {
 
 	t.Run("withConfigFromRemoteVariable", func(t *testing.T) {
 		e := getAuthConfigTestExecutor(t, false)
-		addGitLabRegistryCredentials(&e)
-		addRemoteVariableCredentials(&e)
+		addGitLabRegistryCredentials(e)
+		addRemoteVariableCredentials(e)
 
 		ac := getTestAuthConfig(t, e, imageName)
 		assertCredentials(t, "registry.gitlab.tld:1234", "from_variable", "password", ac, imageName)
@@ -1299,8 +1241,8 @@ func TestAuthConfigOverwritingOrder(t *testing.T) {
 
 	t.Run("withConfigFromLocalVariable", func(t *testing.T) {
 		e := getAuthConfigTestExecutor(t, false)
-		addGitLabRegistryCredentials(&e)
-		addLocalVariableCredentials(&e)
+		addGitLabRegistryCredentials(e)
+		addLocalVariableCredentials(e)
 
 		ac := getTestAuthConfig(t, e, imageName)
 		assertCredentials(t, "registry.gitlab.tld:1234", "from_variable", "password", ac, imageName)
@@ -1308,7 +1250,7 @@ func TestAuthConfigOverwritingOrder(t *testing.T) {
 
 	t.Run("withConfigFromFile", func(t *testing.T) {
 		e := getAuthConfigTestExecutor(t, true)
-		addGitLabRegistryCredentials(&e)
+		addGitLabRegistryCredentials(e)
 
 		ac := getTestAuthConfig(t, e, imageName)
 		assertCredentials(t, "registry.gitlab.tld:1234", "from_file", "password", ac, imageName)
@@ -1316,8 +1258,8 @@ func TestAuthConfigOverwritingOrder(t *testing.T) {
 
 	t.Run("withConfigFromVariableAndFromFile", func(t *testing.T) {
 		e := getAuthConfigTestExecutor(t, true)
-		addGitLabRegistryCredentials(&e)
-		addRemoteVariableCredentials(&e)
+		addGitLabRegistryCredentials(e)
+		addRemoteVariableCredentials(e)
 
 		ac := getTestAuthConfig(t, e, imageName)
 		assertCredentials(t, "registry.gitlab.tld:1234", "from_variable", "password", ac, imageName)
@@ -1325,17 +1267,17 @@ func TestAuthConfigOverwritingOrder(t *testing.T) {
 
 	t.Run("withConfigFromLocalAndRemoteVariable", func(t *testing.T) {
 		e := getAuthConfigTestExecutor(t, true)
-		addGitLabRegistryCredentials(&e)
-		addRemoteVariableCredentials(&e)
+		addGitLabRegistryCredentials(e)
+		addRemoteVariableCredentials(e)
 		testVariableAuthConfigs = `{"auths":{"registry.gitlab.tld:1234":{"auth":"ZnJvbV9sb2NhbF92YXJpYWJsZTpwYXNzd29yZA=="}}}`
-		addLocalVariableCredentials(&e)
+		addLocalVariableCredentials(e)
 
 		ac := getTestAuthConfig(t, e, imageName)
 		assertCredentials(t, "registry.gitlab.tld:1234", "from_variable", "password", ac, imageName)
 	})
 }
 
-func testGetDockerImage(t *testing.T, e executor, imageName string, setClientExpectations func(c *docker.MockClient, imageName string)) {
+func testGetDockerImage(t *testing.T, e *executor, imageName string, setClientExpectations func(c *docker.MockClient, imageName string)) {
 	t.Run("get:"+imageName, func(t *testing.T) {
 		c := new(docker.MockClient)
 		defer c.AssertExpectations(t)
@@ -1350,7 +1292,7 @@ func testGetDockerImage(t *testing.T, e executor, imageName string, setClientExp
 	})
 }
 
-func testDeniesDockerImage(t *testing.T, e executor, imageName string, setClientExpectations func(c *docker.MockClient, imageName string)) {
+func testDeniesDockerImage(t *testing.T, e *executor, imageName string, setClientExpectations func(c *docker.MockClient, imageName string)) {
 	t.Run("deny:"+imageName, func(t *testing.T) {
 		c := new(docker.MockClient)
 		defer c.AssertExpectations(t)
@@ -1426,7 +1368,7 @@ func TestDockerWatchOn_1_12_4(t *testing.T) {
 		return
 	}
 
-	e := executor{
+	e := &executor{
 		AbstractExecutor: executors.AbstractExecutor{
 			ExecutorOptions: executors.ExecutorOptions{
 				Metadata: map[string]string{
@@ -1507,7 +1449,7 @@ func prepareTestDockerConfiguration(t *testing.T, dockerConfig *common.DockerCon
 		t:   t,
 	}
 
-	e := &executor{}
+	e := new(executor)
 	e.client = c
 	e.volumeParser = parser.NewLinuxParser()
 	e.info = types.Info{
@@ -1625,7 +1567,7 @@ func TestDockerCPUSSetting(t *testing.T) {
 			}
 
 			cce := func(t *testing.T, config *container.Config, hostConfig *container.HostConfig) {
-				assert.Equal(t, int64(example.nanocpus), hostConfig.NanoCPUs)
+				assert.Equal(t, example.nanocpus, hostConfig.NanoCPUs)
 			}
 
 			testDockerConfigurationWithJobContainer(t, dockerConfig, cce)
@@ -1718,7 +1660,6 @@ func TestDockerUserNSSetting(t *testing.T) {
 	}
 
 	testDockerConfigurationWithJobContainer(t, dockerConfig, cce)
-
 }
 
 func TestDockerRuntimeSetting(t *testing.T) {
@@ -2006,7 +1947,7 @@ func TestCheckOSType(t *testing.T) {
 }
 
 func TestGetServiceDefinitions(t *testing.T) {
-	e := executor{}
+	e := new(executor)
 	e.Build = &common.Build{
 		Runner: &common.RunnerConfig{},
 	}
@@ -2014,16 +1955,17 @@ func TestGetServiceDefinitions(t *testing.T) {
 	e.Config.Docker = &common.DockerConfig{}
 
 	tests := map[string]struct {
-		services         []*common.DockerService
+		services         []common.Service
 		buildServices    []common.Image
 		allowedServices  []string
 		expectedServices common.Services
 		expectedErr      string
 	}{
 		"all services with proper name and alias": {
-			services: []*common.DockerService{
+			services: []common.Service{
 				{
-					Service: common.Service{Name: "name", Alias: "alias"},
+					Name:  "name",
+					Alias: "alias",
 				},
 			},
 			expectedServices: common.Services{
@@ -2034,9 +1976,10 @@ func TestGetServiceDefinitions(t *testing.T) {
 			},
 		},
 		"build service not in internal images but empty allowed services": {
-			services: []*common.DockerService{
+			services: []common.Service{
 				{
-					Service: common.Service{Name: "name", Alias: "alias"},
+					Name:  "name",
+					Alias: "alias",
 				},
 			},
 			buildServices: []common.Image{
@@ -2055,9 +1998,9 @@ func TestGetServiceDefinitions(t *testing.T) {
 			},
 		},
 		"build service not in internal images": {
-			services: []*common.DockerService{
+			services: []common.Service{
 				{
-					Service: common.Service{Name: "name"},
+					Name: "name",
 				},
 			},
 			buildServices: []common.Image{
@@ -2069,9 +2012,9 @@ func TestGetServiceDefinitions(t *testing.T) {
 			expectedErr:     "invalid image",
 		},
 		"build service not in allowed services but in internal images": {
-			services: []*common.DockerService{
+			services: []common.Service{
 				{
-					Service: common.Service{Name: "name"},
+					Name: "name",
 				},
 			},
 			buildServices: []common.Image{
@@ -2090,9 +2033,9 @@ func TestGetServiceDefinitions(t *testing.T) {
 			},
 		},
 		"empty service name": {
-			services: []*common.DockerService{
+			services: []common.Service{
 				{
-					Service: common.Service{Name: ""},
+					Name: "",
 				},
 			},
 			buildServices: []common.Image{},
